@@ -31,53 +31,53 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define YR_RE_H
 
 #include <ctype.h>
-
-#include <yara/utils.h>
-#include <yara/types.h>
 #include <yara/arena.h>
 #include <yara/sizedstr.h>
+#include <yara/types.h>
+#include <yara/utils.h>
 
-#define RE_NODE_LITERAL             1
-#define RE_NODE_MASKED_LITERAL      2
-#define RE_NODE_ANY                 3
-#define RE_NODE_CONCAT              4
-#define RE_NODE_ALT                 5
-#define RE_NODE_RANGE               6
-#define RE_NODE_STAR                7
-#define RE_NODE_PLUS                8
-#define RE_NODE_CLASS               9
-#define RE_NODE_WORD_CHAR           10
-#define RE_NODE_NON_WORD_CHAR       11
-#define RE_NODE_SPACE               12
-#define RE_NODE_NON_SPACE           13
-#define RE_NODE_DIGIT               14
-#define RE_NODE_NON_DIGIT           15
-#define RE_NODE_EMPTY               16
-#define RE_NODE_ANCHOR_START        17
-#define RE_NODE_ANCHOR_END          18
-#define RE_NODE_WORD_BOUNDARY       19
-#define RE_NODE_NON_WORD_BOUNDARY   20
-#define RE_NODE_RANGE_ANY           21
+#define RE_MAX_RANGE              INT16_MAX
 
+#define RE_NODE_LITERAL           1
+#define RE_NODE_MASKED_LITERAL    2
+#define RE_NODE_ANY               3
+#define RE_NODE_CONCAT            4
+#define RE_NODE_ALT               5
+#define RE_NODE_RANGE             6
+#define RE_NODE_STAR              7
+#define RE_NODE_PLUS              8
+#define RE_NODE_CLASS             9
+#define RE_NODE_WORD_CHAR         10
+#define RE_NODE_NON_WORD_CHAR     11
+#define RE_NODE_SPACE             12
+#define RE_NODE_NON_SPACE         13
+#define RE_NODE_DIGIT             14
+#define RE_NODE_NON_DIGIT         15
+#define RE_NODE_EMPTY             16
+#define RE_NODE_ANCHOR_START      17
+#define RE_NODE_ANCHOR_END        18
+#define RE_NODE_WORD_BOUNDARY     19
+#define RE_NODE_NON_WORD_BOUNDARY 20
+#define RE_NODE_RANGE_ANY         21
 
-#define RE_OPCODE_ANY                   0xA0
-#define RE_OPCODE_LITERAL               0xA2
-#define RE_OPCODE_MASKED_LITERAL        0xA4
-#define RE_OPCODE_CLASS                 0xA5
-#define RE_OPCODE_WORD_CHAR             0xA7
-#define RE_OPCODE_NON_WORD_CHAR         0xA8
-#define RE_OPCODE_SPACE                 0xA9
-#define RE_OPCODE_NON_SPACE             0xAA
-#define RE_OPCODE_DIGIT                 0xAB
-#define RE_OPCODE_NON_DIGIT             0xAC
-#define RE_OPCODE_MATCH                 0xAD
+#define RE_OPCODE_ANY            0xA0
+#define RE_OPCODE_LITERAL        0xA2
+#define RE_OPCODE_MASKED_LITERAL 0xA4
+#define RE_OPCODE_CLASS          0xA5
+#define RE_OPCODE_WORD_CHAR      0xA7
+#define RE_OPCODE_NON_WORD_CHAR  0xA8
+#define RE_OPCODE_SPACE          0xA9
+#define RE_OPCODE_NON_SPACE      0xAA
+#define RE_OPCODE_DIGIT          0xAB
+#define RE_OPCODE_NON_DIGIT      0xAC
+#define RE_OPCODE_MATCH          0xAD
 
-#define RE_OPCODE_MATCH_AT_END          0xB0
-#define RE_OPCODE_MATCH_AT_START        0xB1
-#define RE_OPCODE_WORD_BOUNDARY         0xB2
-#define RE_OPCODE_NON_WORD_BOUNDARY     0xB3
-#define RE_OPCODE_REPEAT_ANY_GREEDY     0xB4
-#define RE_OPCODE_REPEAT_ANY_UNGREEDY   0xB5
+#define RE_OPCODE_MATCH_AT_END        0xB0
+#define RE_OPCODE_MATCH_AT_START      0xB1
+#define RE_OPCODE_WORD_BOUNDARY       0xB2
+#define RE_OPCODE_NON_WORD_BOUNDARY   0xB3
+#define RE_OPCODE_REPEAT_ANY_GREEDY   0xB4
+#define RE_OPCODE_REPEAT_ANY_UNGREEDY 0xB5
 
 #define RE_OPCODE_SPLIT_A               0xC0
 #define RE_OPCODE_SPLIT_B               0xC1
@@ -87,17 +87,15 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define RE_OPCODE_REPEAT_START_UNGREEDY 0xC5
 #define RE_OPCODE_REPEAT_END_UNGREEDY   0xC6
 
-
-#define RE_FLAGS_FAST_REGEXP            0x02
-#define RE_FLAGS_BACKWARDS              0x04
-#define RE_FLAGS_EXHAUSTIVE             0x08
-#define RE_FLAGS_WIDE                   0x10
-#define RE_FLAGS_NO_CASE                0x20
-#define RE_FLAGS_SCAN                   0x40
-#define RE_FLAGS_DOT_ALL                0x80
-#define RE_FLAGS_GREEDY                0x400
-#define RE_FLAGS_UNGREEDY              0x800
-
+#define RE_FLAGS_FAST_REGEXP 0x02
+#define RE_FLAGS_BACKWARDS   0x04
+#define RE_FLAGS_EXHAUSTIVE  0x08
+#define RE_FLAGS_WIDE        0x10
+#define RE_FLAGS_NO_CASE     0x20
+#define RE_FLAGS_SCAN        0x40
+#define RE_FLAGS_DOT_ALL     0x80
+#define RE_FLAGS_GREEDY      0x400
+#define RE_FLAGS_UNGREEDY    0x800
 
 typedef int RE_MATCH_CALLBACK_FUNC(
     const uint8_t* match,
@@ -105,23 +103,15 @@ typedef int RE_MATCH_CALLBACK_FUNC(
     int flags,
     void* args);
 
+int yr_re_ast_create(RE_AST** re_ast);
 
-int yr_re_ast_create(
-    RE_AST** re_ast);
+void yr_re_ast_destroy(RE_AST* re_ast);
 
-void yr_re_ast_destroy(
-    RE_AST* re_ast);
+void yr_re_ast_print(RE_AST* re_ast);
 
-void yr_re_ast_print(
-    RE_AST* re_ast);
-
-SIZED_STRING* yr_re_ast_extract_literal(
-    RE_AST* re_ast);
-
-
-int yr_re_ast_contains_dot_star(
-    RE_AST* re_ast);
+SIZED_STRING* yr_re_ast_extract_literal(RE_AST* re_ast);
 
+int yr_re_ast_has_unbounded_quantifier_for_dot(RE_AST* re_ast);
 
 int yr_re_ast_split_at_chaining_point(
     RE_AST* re_ast,
@@ -129,30 +119,15 @@ int yr_re_ast_split_at_chaining_point(
     int32_t* min_gap,
     int32_t* max_gap);
 
+int yr_re_ast_emit_code(RE_AST* re_ast, YR_ARENA* arena, int backwards_code);
 
-int yr_re_ast_emit_code(
-    RE_AST* re_ast,
-    YR_ARENA* arena,
-    int backwards_code);
+RE_NODE* yr_re_node_create(int type);
 
+void yr_re_node_destroy(RE_NODE* node);
 
-RE_NODE* yr_re_node_create(
-    int type);
-
-
-void yr_re_node_destroy(
-    RE_NODE* node);
-
-
-void yr_re_node_append_child(
-    RE_NODE* node,
-    RE_NODE* child);
-
-
-void yr_re_node_prepend_child(
-    RE_NODE* node,
-    RE_NODE* child);
+void yr_re_node_append_child(RE_NODE* node, RE_NODE* child);
 
+void yr_re_node_prepend_child(RE_NODE* node, RE_NODE* child);
 
 int yr_re_exec(
     YR_SCAN_CONTEXT* context,
@@ -165,7 +140,6 @@ int yr_re_exec(
     void* callback_args,
     int* matches);
 
-
 int yr_re_fast_exec(
     YR_SCAN_CONTEXT* context,
     const uint8_t* code,
@@ -177,31 +151,17 @@ int yr_re_fast_exec(
     void* callback_args,
     int* matches);
 
+int yr_re_parse(const char* re_string, RE_AST** re_ast, RE_ERROR* error);
 
-int yr_re_parse(
-    const char* re_string,
-    RE_AST** re_ast,
-    RE_ERROR* error);
-
-
-int yr_re_parse_hex(
-    const char* hex_string,
-    RE_AST** re_ast,
-    RE_ERROR* error);
-
+int yr_re_parse_hex(const char* hex_string, RE_AST** re_ast, RE_ERROR* error);
 
 int yr_re_compile(
     const char* re_string,
     int flags,
-    YR_ARENA* code_arena,
-    RE** re,
+    YR_ARENA* arena,
+    YR_ARENA_REF* ref,
     RE_ERROR* error);
 
-
-int yr_re_match(
-    YR_SCAN_CONTEXT* context,
-    RE* re,
-    const char* target);
-
+int yr_re_match(YR_SCAN_CONTEXT* context, RE* re, const char* target);
 
 #endif
